.. _api_doc_types:

=====
Types
=====

.. automodule:: schematics.types.base
   :members:
   :undoc-members:

.. automodule:: schematics.types.compound
   :members:
   :undoc-members:


Usage
=====

To learn more about how **Types** are used, visit 
:doc:`Using Types <../usage/types>`
